@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+from pathlib import Path
 
 from PySide6 import QtWidgets
 
@@ -10,10 +10,8 @@ class DatabaseItem(Ui_DatabaseItemUI, QtWidgets.QWidget):
         super().__init__()
         self.setupUi(self)
 
-        items = [f"Any {bus_type} bus"] + [
-            f"{bus_type} {i:>2} only" for i in range(1, 17)
-        ]
+        items = [f"Any {bus_type} bus"] + [f"{bus_type} {i:>2} only" for i in range(1, 17)]
 
-        self.database.setText(database.strip())
+        self.database.setText(str(Path(database.strip())))
         self.bus.addItems(items)
         self.bus.setCurrentIndex(0)
